# subtractor

[![license](https://img.shields.io/github/license/sthagen/subtractor.svg?style=flat)](https://github.com/sthagen/subtractor/blob/default/LICENSE)
[![version](https://img.shields.io/pypi/v/subtractor.svg?style=flat)](https://pypi.python.org/pypi/subtractor/)
[![downloads](https://img.shields.io/pypi/dm/subtractor.svg?style=flat)](https://pypi.python.org/pypi/subtractor/)
[![wheel](https://img.shields.io/pypi/wheel/subtractor.svg?style=flat)](https://pypi.python.org/pypi/subtractor/)
[![supported-versions](https://img.shields.io/pypi/pyversions/subtractor.svg?style=flat)](https://pypi.python.org/pypi/subtractor/)
[![supported-implementations](https://img.shields.io/pypi/implementation/subtractor.svg?style=flat)](https://pypi.python.org/pypi/subtractor/)

Pixels, pixels, pixels.

## Status

Experimental.

**Note**: The default branch is `default`.
